import 'package:flutter/services.dart';

enum TapjoySwiftListener {
  requestDidSucceed,
  requestDidFail,
  contentIsReady,
  contentDidAppear,
  contentDidDisappear,
  didRequestReward,
}

typedef TapjoyiOSListener(TapjoySwiftListener listener);

class TapjoyiOS {
  static final MethodChannel channel = MethodChannel('ios_native');
  static final Map<String, TapjoySwiftListener> tapjoySwiftListener = {
    'requestDidSucceed': TapjoySwiftListener.requestDidSucceed,
    'requestDidFail': TapjoySwiftListener.requestDidFail,
    'contentIsReady': TapjoySwiftListener.contentIsReady,
    'contentDidAppear': TapjoySwiftListener.contentDidAppear,
    'contentDidDisappear': TapjoySwiftListener.contentDidDisappear,
    'didRequestReward': TapjoySwiftListener.didRequestReward,
  };

  static Future<void> setDebugEnabled(bool isDebug) async {
    try {
      await channel.invokeMethod('setDebugEnabled', isDebug);
    } catch (e) {
      print(e.toString());
    }
  }

  static Future<void> setUserConsent(String consent) async {
    try {
      await channel.invokeMethod('setUserConsent', consent);
    } catch (e) {
      print(e.toString());
    }
  }

  static Future<void> connect(String tapjoyKey) async {
    try {
      await channel.invokeMethod('connect', tapjoyKey);
    } catch (e) {
      print(e.toString());
    }
  }

  static Future<void> getPlacement(String placementName) async {
    try {
      await channel.invokeMethod('getPlacement', placementName);
    } catch (e) {
      print(e.toString());
    }
  }

  static Future<void> requestContent(TapjoyiOSListener listener) async {
    try {
      channel.setMethodCallHandler(
          (MethodCall call) async => handleMethod(call, listener));
      await channel.invokeMethod('requestContent');
    } catch (e) {
      print(e.toString());
    }
  }

  static Future<void> handleMethod(
      MethodCall call, TapjoyiOSListener listener) async {
    listener(tapjoySwiftListener[call.method]);
  }

  static Future<void> showContent() async {
    try {
      await channel.invokeMethod('showContent');
    } catch (e) {
      print(e.toString());
    }
  }
}
